@@ -236,6 +236,24 @@ class InteractiveJumpingCondition:
         self.__vars = var
         self.__command = condition
 
+    def get_vars(self) -> List[InteractiveVariable]:
+        """
+        获取公式中的变量
+
+        Returns:
+            List[InteractiveVariable]: 变量
+        """
+        return self.__vars
+
+    def get_condition(self) -> str:
+        """
+        获取表达式
+
+        Returns:
+            str: 表达式
+        """
+        return self.__command
+
     def get_result(self) -> bool:
         """
         计算公式获得结果
@@ -278,6 +296,24 @@ class InteractiveJumpingCommand:
         self.__vars = var
         self.__command = command
 
+    def get_vars(self) -> List[InteractiveVariable]:
+        """
+        获取公式中的变量
+
+        Returns:
+            List[InteractiveVariable]: 变量
+        """
+        return self.__vars
+
+    def get_command(self) -> str:
+        """
+        获取表达式
+
+        Returns:
+            str: 表达式
+        """
+        return self.__command
+
     def run_command(self) -> List["InteractiveVariable"]:
         """
         执行操作
@@ -288,16 +324,22 @@ class InteractiveJumpingCommand:
         if self.__command == "":
             return self.__vars
         for code in self.__command.split(";"):
-            var_name_ = code.split("=")[0]
+            var_name_ = code.split("=")[0].rstrip()
             var_new_value = code.split("=")[1]
             for var in self.__vars:
                 var_name = var.get_id()
                 var_value = var.get_value()
                 var_new_value = var_new_value.replace(var_name, str(var_value))
             var_new_value_calc = eval(var_new_value)
-            for var in self.__vars:
-                if var.get_id() == var_name_:
-                    var._InteractiveVariable__var_value = var_new_value_calc  # type: ignore
+            for idx, var in enumerate(self.__vars):
+                if var.get_name() == var_name_:
+                    self.__vars[idx] = InteractiveVariable(
+                        name=var.get_name(),
+                        var_id=var.get_id(),
+                        var_value=var_new_value_calc,
+                        show=var.is_show(),
+                        random=var.is_random(),
+                    )
         return self.__vars
 
 
@@ -351,7 +393,16 @@ class InteractiveNode:
             self.__info = await self.__parent.get_edge_info(self.__id)
         return self.__info
 
-    async def get_vars(self) -> List[InteractiveVariable]:
+    def get_jumping_command(self) -> InteractiveJumpingCommand:
+        """
+        获取跳转时执行的语句，已自动执行，无需手动调用
+
+        Returns:
+            InteractiveJumpingCommand: 执行的语句
+        """
+        return self.__command
+
+    def get_vars(self) -> List[InteractiveVariable]:
         """
         获取节点的所有变量
 
@@ -385,16 +436,16 @@ class InteractiveNode:
             else:
                 node_button = None
             node_condition = InteractiveJumpingCondition(
-                await self.get_vars(), node["condition"]
+                self.get_vars(), node["condition"]
             )
             node_command = InteractiveJumpingCommand(
-                await self.get_vars(), node["native_action"]
+                self.get_vars(), node["native_action"]
             )
             if "is_default" in node.keys():
                 node_is_default = node["is_default"]
             else:
                 node_is_default = False
-            node_vars = copy.deepcopy(await self.get_vars())
+            node_vars = copy.deepcopy(self.get_vars())
             nodes.append(
                 InteractiveNode(
                     self.__parent,
@@ -499,7 +550,7 @@ class InteractiveGraph:
         """
         self.__parent = video
         self.__skin = skin
-        self.__node = self.__node = InteractiveNode(self.__parent, 0, root_cid, [])
+        self.__node = InteractiveNode(self.__parent, 0, root_cid, [])
 
     def get_video(self) -> "InteractiveVideo":
         """
@@ -546,11 +597,13 @@ class InteractiveGraph:
             var_list.append(
                 InteractiveVariable(var_name, var_id, var_value, var_show, random)
             )
-        self.__node._InteractiveNode__command = InteractiveJumpingCommand(  # type: ignore
-            var_list
+        self.__node = InteractiveNode(
+            video=self.__parent,
+            node_id=edge_info["edge_id"],
+            cid=self.__node.get_cid(),
+            vars=var_list,
+            native_command=InteractiveJumpingCommand(var_list),
         )
-        self.__node._InteractiveNode__vars = var_list  # type: ignore
-        self.__node._InteractiveNode__id = edge_info["edge_id"]
         return self.__node
 
     async def get_children(self) -> List["InteractiveNode"]:
@@ -779,7 +832,9 @@ class InteractiveVideoDownloader(AsyncEvent):
         """
         super().__init__()
         self.__video = video
-        self.__download_func = self_download_func if self_download_func else self.__download
+        self.__download_func = (
+            self_download_func if self_download_func else self.__download
+        )
         self.__task = None
         self.__out = out
         self.__mode = downloader_mode
@@ -863,9 +918,7 @@ class InteractiveVideoDownloader(AsyncEvent):
         if n.get_node_id() not in edges_info:
             createEdge(n.get_node_id())
         edges_info[n.get_node_id()]["cid"] = n.get_cid()
-        edges_info[n.get_node_id()]["vars"] = [
-            var2dict(var) for var in (await n.get_vars())
-        ]
+        edges_info[n.get_node_id()]["vars"] = [var2dict(var) for var in n.get_vars()]
 
         while queue:
             # 出队
@@ -923,10 +976,10 @@ class InteractiveVideoDownloader(AsyncEvent):
                         "text": n.get_self_button().get_text(),
                         "align": n.get_self_button().get_align(),
                         "pos": n.get_self_button().get_pos(),
-                        "condition": n.get_jumping_condition()._InteractiveJumpingCondition__command,  # type: ignore
+                        "condition": n.get_jumping_condition().get_condition(),  # type: ignore
                         "jump_type": await now_node.get_jumping_type(),
                         "is_default": n.is_default(),
-                        "command": n._InteractiveNode__command._InteractiveJumpingCommand__command,  # type: ignore
+                        "command": n.get_jumping_command().get_command(),  # type: ignore
                     }
                 )
                 # # 所有可达顶点 ID 入队
@@ -1156,12 +1209,12 @@ class InteractiveVideoDownloader(AsyncEvent):
                     node_info_dict[cur_node.get_node_id()] = cur_node_info_class
                     for cur_node_child in cur_node_children:
                         script_label = ""
-                        if cur_node_child.get_jumping_condition()._InteractiveJumpingCondition__command != "":  # type: ignore
-                            script_label = script_label + "Condition: [" + cur_node_child.get_jumping_condition()._InteractiveJumpingCondition__command + "]"  # type: ignore
-                            if cur_node_child._InteractiveNode__command._InteractiveJumpingCommand__command != "":  # type: ignore
-                                script_label = script_label + "\nNative Command: [" + cur_node_child._InteractiveNode__command._InteractiveJumpingCommand__command + "]"  # type: ignore
-                        elif cur_node_child._InteractiveNode__command._InteractiveJumpingCommand__command != "":  # type: ignore
-                            script_label = script_label + "\nNative Command: [" + cur_node_child._InteractiveNode__command._InteractiveJumpingCommand__command + "]"  # type: ignore
+                        if cur_node_child.get_jumping_condition().get_condition() != "":  # type: ignore
+                            script_label = script_label + "Condition: [" + cur_node_child.get_jumping_condition().get_condition() + "]"  # type: ignore
+                            if cur_node_child.get_jumping_command().get_command() != "":  # type: ignore
+                                script_label = script_label + "\nNative Command: [" + cur_node_child.get_jumping_command().get_command() + "]"  # type: ignore
+                        elif cur_node_child.get_jumping_command().get_command() != "":  # type: ignore
+                            script_label = script_label + "\nNative Command: [" + cur_node_child.get_jumping_command().get_command() + "]"  # type: ignore
                         scripts.append(
                             {
                                 "from": cur_node.get_node_id(),
@@ -1188,7 +1241,7 @@ class InteractiveVideoDownloader(AsyncEvent):
             else:
                 graph_content += f'\t{node_info_key} [label="{node_info_item}"]\n'
         vars_string = "Variables: "
-        for var in await (await graph.get_root_node()).get_vars():
+        for var in (await graph.get_root_node()).get_vars():
             var_attribute = ""
             if var.is_random():
                 var_attribute = "Random"
@@ -1243,9 +1296,7 @@ class InteractiveVideoDownloader(AsyncEvent):
         if n.get_node_id() not in edges_info:
             createEdge(n.get_node_id())
         edges_info[n.get_node_id()]["cid"] = n.get_cid()
-        edges_info[n.get_node_id()]["vars"] = [
-            var2dict(var) for var in (await n.get_vars())
-        ]
+        edges_info[n.get_node_id()]["vars"] = [var2dict(var) for var in n.get_vars()]
 
         while queue:
             # 出队
@@ -1299,10 +1350,10 @@ class InteractiveVideoDownloader(AsyncEvent):
                         "text": n.get_self_button().get_text(),
                         "align": n.get_self_button().get_align(),
                         "pos": n.get_self_button().get_pos(),
-                        "condition": n.get_jumping_condition()._InteractiveJumpingCondition__command,  # type: ignore
+                        "condition": n.get_jumping_condition().get_condition(),  # type: ignore
                         "jump_type": await now_node.get_jumping_type(),
                         "is_default": n.is_default(),
-                        "command": n._InteractiveNode__command._InteractiveJumpingCommand__command,  # type: ignore
+                        "command": n.get_jumping_command().get_command(),  # type: ignore
                     }
                 )
                 # # 所有可达顶点 ID 入队
