@@ -2097,6 +2097,7 @@ class VideoQuality(Enum):
     - _480P: 清晰 480P
     - _720P: 高清 720P60
     - _1080P: 高清 1080P
+    - AI_REPAIR: 智能修复（人工智能修复画质）
     - _1080P_PLUS: 高清 1080P 高码率
     - _1080P_60: 高清 1080P 60 帧码率
     - _4K: 超清 4K
@@ -2109,6 +2110,7 @@ class VideoQuality(Enum):
     _480P = 32
     _720P = 64
     _1080P = 80
+    AI_REPAIR = 100
     _1080P_PLUS = 112
     _1080P_60 = 116
     _4K = 120
